==> jc-1.4.0.tar.gz: java/nio/channels/Pipe__24SinkChannel.h <==
// public abstract class java.nio.channels.Pipe$SinkChannel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8a9bac808797868c java_nio_channels_Pipe__24SinkChannel
// @dep_class b95b712f8b955018 java_nio_channels_SelectableChannel
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel
// @dep_class 9d3bd8ebcf76e5ce java_nio_channels_spi_AbstractSelectableChannel

// header file dependencies
// @dep_header java_nio_channels_spi_AbstractSelectableChannel

#include "java/nio/channels/spi/AbstractSelectableChannel.h"

#ifndef _JC_java_nio_channels_Pipe__24SinkChannel_H_
#define _JC_java_nio_channels_Pipe__24SinkChannel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_java_nio_channels_Pipe__24SinkChannel$sub_refs	_jc_java_nio_channels_Pipe__24SinkChannel$sub_refs;
typedef struct _jc_java_nio_channels_Pipe__24SinkChannel$sub_nonrefs	_jc_java_nio_channels_Pipe__24SinkChannel$sub_nonrefs;
typedef struct _jc_java_nio_channels_Pipe__24SinkChannel$refs	_jc_java_nio_channels_Pipe__24SinkChannel$refs;
typedef struct _jc_java_nio_channels_Pipe__24SinkChannel$nonrefs	_jc_java_nio_channels_Pipe__24SinkChannel$nonrefs;
typedef struct _jc_java_nio_channels_Pipe__24SinkChannel$object	_jc_java_nio_channels_Pipe__24SinkChannel$object;

typedef const struct _jc_java_nio_channels_Pipe__24SinkChannel$vmethods	_jc_java_nio_channels_Pipe__24SinkChannel$vmethods;
typedef const struct _jc_java_nio_channels_Pipe__24SinkChannel$vtable	_jc_java_nio_channels_Pipe__24SinkChannel$vtable;
typedef const struct _jc_java_nio_channels_Pipe__24SinkChannel$vtype	_jc_java_nio_channels_Pipe__24SinkChannel$vtype;

// Constructors
extern void _jc_java_nio_channels_Pipe__24SinkChannel$method$_init$21bbe82c9df5d674(_jc_env *, struct _jc_java_nio_channels_Pipe__24SinkChannel$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);

// Virtual methods
extern jint _jc_java_nio_channels_Pipe__24SinkChannel$method$validOps$2ee4dac018721573(_jc_env *, struct _jc_java_nio_channels_Pipe__24SinkChannel$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_Pipe__24SinkChannel$method_info$validOps$2ee4dac018721573;

// Virtual methods structure
struct _jc_java_nio_channels_Pipe__24SinkChannel$vmethods {
	jint	(*validOps$2ee4dac018721573)(_jc_env *, struct _jc_java_nio_channels_Pipe__24SinkChannel$object *);
};

// Vtable
struct _jc_java_nio_channels_Pipe__24SinkChannel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
	_jc_java_nio_channels_SelectableChannel$vmethods	java_nio_channels_SelectableChannel;
	_jc_java_nio_channels_spi_AbstractSelectableChannel$vmethods	java_nio_channels_spi_AbstractSelectableChannel;
	_jc_java_nio_channels_Pipe__24SinkChannel$vmethods	java_nio_channels_Pipe__24SinkChannel;
};

// Vtype
struct _jc_java_nio_channels_Pipe__24SinkChannel$vtype {
	_jc_type			type;
	_jc_java_nio_channels_Pipe__24SinkChannel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_Pipe__24SinkChannel$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_Pipe__24SinkChannel$refs {
    _jc_java_nio_channels_Pipe__24SinkChannel$sub_refs	java_nio_channels_Pipe__24SinkChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_refs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_SelectableChannel$sub_refs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_Pipe__24SinkChannel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_Pipe__24SinkChannel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_nio_channels_SelectableChannel$sub_nonrefs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_nonrefs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_Pipe__24SinkChannel$sub_nonrefs	java_nio_channels_Pipe__24SinkChannel;
};

// Object instance structure
struct _jc_java_nio_channels_Pipe__24SinkChannel$object {
	_jc_java_nio_channels_Pipe__24SinkChannel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_Pipe__24SinkChannel$vtype	*vtype;
	_jc_java_nio_channels_Pipe__24SinkChannel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_Pipe__24SinkChannel$vtype _jc_java_nio_channels_Pipe__24SinkChannel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_Pipe__24SinkChannel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_Pipe__24SinkChannel$class_object;

#endif	/* _JC_java_nio_channels_Pipe__24SinkChannel_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/Pipe__24SinkChannel.h <==
// public abstract class java.nio.channels.Pipe$SinkChannel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8a9bac808797868c java_nio_channels_Pipe__24SinkChannel
// @dep_class b95b712f8b955018 java_nio_channels_SelectableChannel
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel
// @dep_class 9d3bd8ebcf76e5ce java_nio_channels_spi_AbstractSelectableChannel

// header file dependencies
// @dep_header java_nio_channels_spi_AbstractSelectableChannel

#include "java/nio/channels/spi/AbstractSelectableChannel.h"

#ifndef _JC_java_nio_channels_Pipe__24SinkChannel_H_
#define _JC_java_nio_channels_Pipe__24SinkChannel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_java_nio_channels_Pipe__24SinkChannel$sub_refs	_jc_java_nio_channels_Pipe__24SinkChannel$sub_refs;
typedef struct _jc_java_nio_channels_Pipe__24SinkChannel$sub_nonrefs	_jc_java_nio_channels_Pipe__24SinkChannel$sub_nonrefs;
typedef struct _jc_java_nio_channels_Pipe__24SinkChannel$refs	_jc_java_nio_channels_Pipe__24SinkChannel$refs;
typedef struct _jc_java_nio_channels_Pipe__24SinkChannel$nonrefs	_jc_java_nio_channels_Pipe__24SinkChannel$nonrefs;
typedef struct _jc_java_nio_channels_Pipe__24SinkChannel$object	_jc_java_nio_channels_Pipe__24SinkChannel$object;

typedef const struct _jc_java_nio_channels_Pipe__24SinkChannel$vmethods	_jc_java_nio_channels_Pipe__24SinkChannel$vmethods;
typedef const struct _jc_java_nio_channels_Pipe__24SinkChannel$vtable	_jc_java_nio_channels_Pipe__24SinkChannel$vtable;
typedef const struct _jc_java_nio_channels_Pipe__24SinkChannel$vtype	_jc_java_nio_channels_Pipe__24SinkChannel$vtype;

// Constructors
extern void _jc_java_nio_channels_Pipe__24SinkChannel$method$_init$21bbe82c9df5d674(_jc_env *, struct _jc_java_nio_channels_Pipe__24SinkChannel$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_nio_channels_Pipe__24SinkChannel$method$validOps$2ee4dac018721573(_jc_env *, struct _jc_java_nio_channels_Pipe__24SinkChannel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_Pipe__24SinkChannel$method_info$validOps$2ee4dac018721573;

// Virtual methods structure
struct _jc_java_nio_channels_Pipe__24SinkChannel$vmethods {
	jint	(*validOps$2ee4dac018721573)(_jc_env *, struct _jc_java_nio_channels_Pipe__24SinkChannel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_channels_Pipe__24SinkChannel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
	_jc_java_nio_channels_SelectableChannel$vmethods	java_nio_channels_SelectableChannel;
	_jc_java_nio_channels_spi_AbstractSelectableChannel$vmethods	java_nio_channels_spi_AbstractSelectableChannel;
	_jc_java_nio_channels_Pipe__24SinkChannel$vmethods	java_nio_channels_Pipe__24SinkChannel;
};

// Vtype
struct _jc_java_nio_channels_Pipe__24SinkChannel$vtype {
	_jc_type			type;
	_jc_java_nio_channels_Pipe__24SinkChannel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_Pipe__24SinkChannel$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_Pipe__24SinkChannel$refs {
    _jc_java_nio_channels_Pipe__24SinkChannel$sub_refs	java_nio_channels_Pipe__24SinkChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_refs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_SelectableChannel$sub_refs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_Pipe__24SinkChannel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_Pipe__24SinkChannel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_nio_channels_SelectableChannel$sub_nonrefs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_nonrefs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_Pipe__24SinkChannel$sub_nonrefs	java_nio_channels_Pipe__24SinkChannel;
};

// Object instance structure
struct _jc_java_nio_channels_Pipe__24SinkChannel$object {
	_jc_java_nio_channels_Pipe__24SinkChannel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_Pipe__24SinkChannel$vtype	*vtype;
	_jc_java_nio_channels_Pipe__24SinkChannel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_Pipe__24SinkChannel$vtype _jc_java_nio_channels_Pipe__24SinkChannel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_Pipe__24SinkChannel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_Pipe__24SinkChannel$class_object;

#endif	/* _JC_java_nio_channels_Pipe__24SinkChannel_H_ */
